use mquery::query::{
    ops::{Arithmetic, Comparison, Logical},
    Duration, Label, Metric, Offset, QueryExt, Scalar, Unit,
};

mod utils;

// Arbitrary queries to test whether they produce valid syntax
// The server will return an error if there is a syntax error and the test will fail

#[tokio::test]
async fn basic_query_with_labels() {
    let query = Metric::new("test_metric").labels([
        Label::Eq("eq", "eqvalue"),
        Label::RxEq("rxeq", ".*"),
        Label::RxNe("rxne", ".*"),
    ]);
    utils::send_query(query).await.unwrap();
}

#[tokio::test]
async fn basic_subquery() {
    let query = Metric::new("test_metric")
        .labels([
            Label::Eq("eq", "eqvalue"),
            Label::RxEq("rxeq", ".*"),
            Label::RxNe("rxne", ".*"),
        ])
        .subquery(Duration(30, Unit::Day))
        .resolution(Duration(10, Unit::Min))
        .offset(Offset(1, Unit::Sec));
    utils::send_query(query).await.unwrap();
}

#[tokio::test]
async fn arithmetic_ops() {
    let query = Metric::new("test_metric")
        .add(Metric::new("another_metric"))
        .add(Scalar(0.5));
    utils::send_query(query).await.unwrap();
}

#[tokio::test]
async fn comp_ops() {
    let query = Metric::new("test_metric")
        .cmp_eq(Metric::new("another_metric"))
        .cmp_ne_bool(Scalar(0.5));
    utils::send_query(query).await.unwrap();
}

#[tokio::test]
async fn logic_ops() {
    let query = Metric::new("test_metric")
        .and(Metric::new("another_metric"))
        .and(Metric::new("third_metric"));
    utils::send_query(query).await.unwrap();
}
